==> libsysactivity_0.5.4.orig.tar.gz: libsysactivity-0.5.4/src/Linux/libsysactivity.h <==
/*
 * libsysactivity
 * http://sourceforge.net/projects/libsysactivity/
 * Copyright (c) 2009, 2010 Carlos Olmedo Escobar <carlos.olmedo.e@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef LIBSYSACTIVITY_H_
#define LIBSYSACTIVITY_H_

#include <stdint.h>
#include <unistd.h>
#include <linux/dm-ioctl.h>

#ifdef __cplusplus
extern "C" {
#endif

#if __GNUC__ >= 4
	#define SA_EXPORT __attribute__ ((visibility("default")))
#else
	#define SA_EXPORT
#endif

#define SA_CPU
#define SA_OPEN_CPU
#define SA_CLOSE_CPU
#define SA_CPU_ID
#define SA_CPU_USER
#define SA_CPU_NICE
#define SA_CPU_SYSTEM
#define SA_CPU_IDLE
#define SA_CPU_WAITING_FOR_IO
#define SA_CPU_HARDWARE_IRQ
#define SA_CPU_SOFTWARE_IRQ
#define SA_CPU_STOLEN
#undef SA_CPU_INTR
#include "cpu.h"

#define SA_DATA_STORAGE
#define SA_OPEN_DATA_STORAGE
#define SA_CLOSE_DATA_STORAGE
#define SA_DATA_STORAGE_NAME DM_NAME_LEN
#define SA_DATA_STORAGE_READS
#define SA_DATA_STORAGE_READS_MERGED
#define SA_DATA_STORAGE_SECTORS_READ
#define SA_DATA_STORAGE_TIME_SPENT_READING
#define SA_DATA_STORAGE_WRITES
#define SA_DATA_STORAGE_SECTORS_WRITTEN
#define SA_DATA_STORAGE_TIME_SPENT_WRITING
#undef SA_DATA_STORAGE_BYTES_READ
#undef SA_DATA_STORAGE_BYTES_WRITTEN
#include "data_storage.h"

#define SA_MEMORY
#define SA_OPEN_MEMORY
#define SA_CLOSE_MEMORY
#define SA_MEMORY_TOTAL
#define SA_MEMORY_FREE
#define SA_MEMORY_ACTIVE
#define SA_MEMORY_INACTIVE
#define SA_MEMORY_BUFFERS
#define SA_MEMORY_SWAP_TOTAL
#define SA_MEMORY_SWAP_FREE
#define SA_MEMORY_SWAP_CACHED
#undef SA_MEMORY_WIRED
#define SA_MEMORY_CACHED
#define SA_MEMORY_DIRTY
#undef SA_MEMORY_EXECUTABLE
#undef SA_MEMORY_FILES
#undef SA_MEMORY_LOCKED
#define SA_SWAP_NAME 256
#define SA_SWAP_TOTAL
#define SA_SWAP_FREE
#define SA_SWAP_TYPE
#include "memory.h"

#define SA_NETWORK
#define SA_OPEN_NETWORK
#define SA_CLOSE_NETWORK
#define SA_NETWORK_INTERFACE_NAME 64
#define SA_NETWORK_INTERFACE_RECEIVED_BYTES
#define SA_NETWORK_INTERFACE_RECEIVED_PACKETS
#define SA_NETWORK_INTERFACE_RECEIVED_ERRORS
#define SA_NETWORK_INTERFACE_RECEIVED_DROP
#define SA_NETWORK_INTERFACE_RECEIVED_FIFO
#define SA_NETWORK_INTERFACE_RECEIVED_COMPRESSED
#undef SA_NETWORK_INTERFACE_RECEIVED_MULTICAST
#define SA_NETWORK_INTERFACE_SENT_BYTES
#define SA_NETWORK_INTERFACE_SENT_PACKETS
#define SA_NETWORK_INTERFACE_SENT_ERRORS
#define SA_NETWORK_INTERFACE_SENT_DROP
#define SA_NETWORK_INTERFACE_SENT_FIFO
#define SA_NETWORK_INTERFACE_SENT_COMPRESSED
#undef SA_NETWORK_INTERFACE_SENT_MULTICAST
#include "network.h"

#define SA_PROCESS
#define SA_OPEN_PROCESS
#define SA_CLOSE_PROCESS
#define SA_PROCESS_PID
#define SA_PROCESS_UID
#define SA_PROCESS_GID
#define SA_PROCESS_FILENAME 256
#define SA_PROCESS_CMDLINE 256
#define SA_PROCESS_STATE
#define SA_PROCESS_PARENT_PID
#define SA_PROCESS_PGRP
#define SA_PROCESS_SID
#define SA_PROCESS_TTY
#define SA_PROCESS_USER_TIME
#define SA_PROCESS_SYS_TIME
#define SA_PROCESS_NICE
#define SA_PROCESS_THREADS
#define SA_PROCESS_START_TIME
#define SA_PROCESS_VM_SIZE
#define SA_PROCESS_RSS
#include "process.h"

#ifdef __cplusplus
}
#endif

#endif /* LIBSYSACTIVITY_H_ */

==> libsysactivity_0.6.2.orig.tar.gz: libsysactivity-0.6.2/src/Linux/libsysactivity.h <==
/*
 * libsysactivity
 * http://sourceforge.net/projects/libsysactivity/
 * Copyright (c) 2009, 2010 Carlos Olmedo Escobar <carlos.olmedo.e@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef LIBSYSACTIVITY_H_
#define LIBSYSACTIVITY_H_

#include <stdint.h>
#include <unistd.h>
#include <linux/dm-ioctl.h>

#ifdef __cplusplus
extern "C" {
#endif

#define SA_OPEN_CPU
#define SA_CLOSE_CPU
#define SA_SMP_CAPABLE
#define SA_CPU_ID
#define SA_CPU_USER
#define SA_CPU_NICE
#define SA_CPU_SYSTEM
#define SA_CPU_IDLE
#define SA_CPU_WAITING_FOR_IO
#define SA_CPU_HARDWARE_IRQ
#define SA_CPU_SOFTWARE_IRQ
#define SA_CPU_STOLEN
#undef SA_CPU_INTR

#define SA_OPEN_DISK
#define SA_CLOSE_DISK
#define SA_DISK_NAME DM_NAME_LEN
#define SA_DISK_READS
#define SA_DISK_READS_MERGED
#define SA_DISK_SECTORS_READ
#define SA_DISK_TIME_SPENT_READING
#define SA_DISK_WRITES
#define SA_DISK_SECTORS_WRITTEN
#define SA_DISK_TIME_SPENT_WRITING
#undef SA_DISK_BYTES_READ
#undef SA_DISK_BYTES_WRITTEN

#define SA_OPEN_MEMORY
#define SA_CLOSE_MEMORY
#define SA_MEMORY_TOTAL
#define SA_MEMORY_FREE
#define SA_MEMORY_ACTIVE
#define SA_MEMORY_INACTIVE
#define SA_MEMORY_BUFFERS
#define SA_MEMORY_SWAP_TOTAL
#define SA_MEMORY_SWAP_FREE
#define SA_MEMORY_SWAP_CACHED
#undef SA_MEMORY_WIRED
#define SA_MEMORY_CACHED
#define SA_MEMORY_DIRTY
#undef SA_MEMORY_EXECUTABLE
#undef SA_MEMORY_FILES
#undef SA_MEMORY_LOCKED

#define SA_OPEN_NET
#define SA_CLOSE_NET
#define SA_NET_INTERFACE_NAME 64
#define SA_NET_INTERFACE_RECEIVED_BYTES
#define SA_NET_INTERFACE_RECEIVED_PACKETS
#define SA_NET_INTERFACE_RECEIVED_ERRORS
#define SA_NET_INTERFACE_RECEIVED_DROP
#define SA_NET_INTERFACE_RECEIVED_FIFO
#define SA_NET_INTERFACE_RECEIVED_COMPRESSED
#undef SA_NET_INTERFACE_RECEIVED_MULTICAST
#define SA_NET_INTERFACE_SENT_BYTES
#define SA_NET_INTERFACE_SENT_PACKETS
#define SA_NET_INTERFACE_SENT_ERRORS
#define SA_NET_INTERFACE_SENT_DROP
#define SA_NET_INTERFACE_SENT_FIFO
#define SA_NET_INTERFACE_SENT_COMPRESSED
#undef SA_NET_INTERFACE_SENT_MULTICAST

#define SA_OPEN_PROCESS
#define SA_CLOSE_PROCESS
#define SA_PROCESS_PID
#define SA_PROCESS_UID
#define SA_PROCESS_GID
#define SA_PROCESS_FILENAME 1024 // Don't use FILENAME_MAX as the size of an array in which to store a file name! You can't possibly make an array that big!
#define SA_PROCESS_CMDLINE 384
#define SA_PROCESS_PARENT_PID
#define SA_PROCESS_PGRP
#define SA_PROCESS_SID
#define SA_PROCESS_TTY
#define SA_PROCESS_NICE
#define SA_PROCESS_START_TIME

#define SA_PROCESS_STATE
#define SA_PROCESS_USER_TIME
#define SA_PROCESS_SYS_TIME
#define SA_PROCESS_THREADS
#define SA_PROCESS_VM_SIZE
#define SA_PROCESS_RSS

#define SA_OPEN_SWAP
#define SA_CLOSE_SWAP
#define SA_SWAP_NAME 1024
#define SA_SWAP_TOTAL
#define SA_SWAP_FREE
#define SA_SWAP_TYPE

#include "global.h"

#ifdef __cplusplus
}
#endif

#endif /* LIBSYSACTIVITY_H_ */
